Struct NvmExpressPassThruCommandPacket
Source #[repr(C)]
pub struct NvmExpressPassThruCommandPacket {
pub command_timeout: u64,
pub transfer_buffer: *mut c_void,
pub transfer_length: u32,
pub meta_data_buffer: *mut c_void,
pub meta_data_length: u32,
pub queue_type: NvmExpressQueueType,
pub nvme_cmd: *const NvmExpressCommand,
pub nvme_completion: *mut NvmExpressCompletion,
}
command_timeout: u64
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.