Struct NvmExpressPassThruProtocol
Source #[repr(C)]
pub struct NvmExpressPassThruProtocol {
pub mode: *const NvmExpressPassThruMode,
pub pass_thru: unsafe extern "efiapi" fn(this: *mut Self, namespace_id: u32, packet: *mut NvmExpressPassThruCommandPacket, event: *mut c_void) -> Status,
pub get_next_namespace: unsafe extern "efiapi" fn(this: *const Self, namespace_id: *mut u32) -> Status,
pub build_device_path: unsafe extern "efiapi" fn(this: *const Self, namespace_id: u32, device_path: *mut *const DevicePathProtocol) -> Status,
pub get_namespace: unsafe extern "efiapi" fn(this: *const Self, device_path: *const DevicePathProtocol, namespace_id: *mut u32) -> Status,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.