pub struct NvmExpressPassThruAttributes(/* private fields */);Expand description
Represents the EFI_NVM_EXPRESS_PASS_THRU_ATTRIBUTES_* defines from the UEFI specification.
UEFI Specification Description
Tells if the interface is for physical NVM Express controllers or logical NVM Express controllers.
Drivers for non-RAID NVM Express controllers will set both the PHYSICAL and the LOGICAL bit.
Drivers for RAID controllers that allow access to the underlying physical controllers will produces
two protocol instances. One where the LOGICAL bit is set (representing the logical RAID volume),
and one where the PHYSICAL bit is set, which can be used to access the underlying NVMe controllers.
Drivers for RAID controllers that do not allow access of the underlying NVMe controllers will only
produce one protocol instance for the logical RAID volume with the LOGICAL bit set.
Implementations
Sourceimpl NvmExpressPassThruAttributes
impl NvmExpressPassThruAttributes
Sourcepub const PHYSICAL: Self
pub const PHYSICAL: Self
If this bit is set, the interface is for directly addressable namespaces.
Sourcepub const LOGICAL: Self
pub const LOGICAL: Self
If this bit is set, the interface is for a single logical namespace comprising multiple namespaces.
Sourcepub const NONBLOCKIO: Self
pub const NONBLOCKIO: Self
If this bit is set, the interface supports both blocking and non-blocking I/O.
- All interfaces must support blocking I/O, but this bit indicates that non-blocking I/O is also supported.
Sourcepub const CMD_SET_NVM: Self
pub const CMD_SET_NVM: Self
If this bit is set, the interface supports the NVM Express command set.
Sourceimpl NvmExpressPassThruAttributes
impl NvmExpressPassThruAttributes
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl NvmExpressPassThruAttributes
impl NvmExpressPassThruAttributes
Sourcepub const fn iter(&self) -> Iter<NvmExpressPassThruAttributes>
pub const fn iter(&self) -> Iter<NvmExpressPassThruAttributes>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<NvmExpressPassThruAttributes>
pub const fn iter_names(&self) -> IterNames<NvmExpressPassThruAttributes>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.